==> haskell-gitrev-1.3.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-gitrev.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gitrev
version: 1.3.1
id: gitrev-1.3.1-EQtKoLk36BRBfzqBgzf47p
key: gitrev-1.3.1-EQtKoLk36BRBfzqBgzf47p
license: BSD-3-Clause
maintainer: acfoltzer@galois.com
author: Adam C. Foltzer
homepage: https://github.com/acfoltzer/gitrev
synopsis: Compile git revision info into Haskell projects
description:
    Some handy Template Haskell splices for including the current git hash and branch in the code of your project. Useful for including in panic messages, @--version@ output, or diagnostic info for more informative bug reports.
category: Development
abi: be8d0f889c5df82885fad3608203bf50
exposed: True
exposed-modules:
    Development.GitRev
import-dirs: /usr/lib/ghc-8.6.3/site-local/gitrev-1.3.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/gitrev-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/gitrev-1.3.1
hs-libraries: HSgitrev-1.3.1-EQtKoLk36BRBfzqBgzf47p
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    directory-1.3.3.0 filepath-1.4.2.1 process-1.6.3.0
    template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-gitrev/html/gitrev.haddock
haddock-html: /usr/share/doc/haskell-gitrev/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gitrev-1.3.1-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-gitrev.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: gitrev
version: 1.3.1
id: gitrev-1.3.1-28bODUJmuLsJT3tLybQkQz
key: gitrev-1.3.1-28bODUJmuLsJT3tLybQkQz
license: BSD-3-Clause
maintainer: acfoltzer@galois.com
author: Adam C. Foltzer
homepage: https://github.com/acfoltzer/gitrev
synopsis: Compile git revision info into Haskell projects
description:
    Some handy Template Haskell splices for including the current git hash and branch in the code of your project. Useful for including in panic messages, @--version@ output, or diagnostic info for more informative bug reports.
category: Development
abi: 8c0cdca4a06c0b12314872f6dc5a3f82
exposed: True
exposed-modules:
    Development.GitRev
import-dirs: /usr/lib/ghc-8.6.4/site-local/gitrev-1.3.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/gitrev-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/gitrev-1.3.1
hs-libraries: HSgitrev-1.3.1-28bODUJmuLsJT3tLybQkQz
depends:
    base-4.12.0.0 base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr
    directory-1.3.3.0 filepath-1.4.2.1 process-1.6.5.0
    template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-gitrev/html/gitrev.haddock
haddock-html: /usr/share/doc/haskell-gitrev/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
